@@ -32,13 +32,14 @@ from .. import glyphs
 from ..apidoc import api_end, api_start
 from ..caching import cached_unary_operator
 from ..constraints import (AbsoluteValueConstraint, Constraint,
-                           MatrixNormConstraint, SOCConstraint,
-                           VectorNormConstraint, SpectralNormConstraint,
-                           NuclearNormConstraint)
+                           MatrixNormConstraint, NuclearNormConstraint,
+                           SOCConstraint, SpectralNormConstraint,
+                           VectorNormConstraint)
 from ..legacy import throw_deprecation_warning
 from .data import (convert_and_refine_arguments, convert_operands, cvx2np,
                    make_fraction)
 from .exp_affine import AffineExpression, ComplexAffineExpression
+from .exp_sqnorm import SquaredNorm
 from .expression import Expression, refine_operands, validate_prediction
 
 _API_START = api_start(globals())
@@ -395,10 +396,9 @@ class Norm(Expression):
             p, q = self.p, self.q
 
             if p == q and p == 2:
-                square = (self._x | self._x)
-                # NOTE: AffineExpression.__or__ creates a fresh expression.
-                square._symbStr = glyphs.squared(self.string)
-                return square
+                result = SquaredNorm(self._x)
+                result._symbStr = glyphs.squared(self.string)
+                return result
             else:
                 raise NotImplementedError(
                     "You may only square an Euclidean or Frobenius norm.")
