@@ -801,6 +801,20 @@ class Expression(ABC):
         else:
             return NotImplemented
 
+    @convert_operands(scalarRHS=True)
+    def __pow__(self, other):
+        if type(self.refined) != type(self):
+            return self.refined.__pow__(other)
+        else:
+            return NotImplemented
+
+    @convert_operands(scalarLHS=True)
+    def __rpow__(self, other):
+        if type(self.refined) != type(self):
+            return self.refined.__rpow__(other)
+        else:
+            return NotImplemented
+
     @convert_operands(horiCat=True)
     def __and__(self, other):
         if type(self.refined) != type(self):
@@ -943,10 +957,10 @@ def refine_operands(stop_at_affine=False):
 
     This decorator is supposed to be used on all constraint creating binary
     operator methods so that degenerated instances (e.g. a complex affine
-    expression an imaginary part of zero) can occur but are not used in
+    expression with an imaginary part of zero) can occur but are not used in
     constraints. This speeds up many computations involving expressions as these
-    degenerate cases do not need to be detected. See also :attr:`type`, which
-    describes the refined version of an expression as well.
+    degenerate cases do not need to be detected. Note that
+    :attr:`Expression.type` also refers to the refined version of an expression.
 
     :param bool stop_at_affine: Do not refine any affine expressions, in
         particular do not refine complex affine expressions to real ones.
