@@ -167,7 +167,7 @@ class Solver(ABC):
 
         An exception is raised when the solver is not available on the user's
         platform. No exception is raised when the problem type is not supported
-        as the problem is first imported when the user calls :meth:`solve`.
+        as the problem is first imported when a solution is requested.
 
         Solver implementations are supposed to also implement :meth:`__init__`,
         but with ``problem`` as its only positional argument, and using
@@ -284,7 +284,7 @@ class Solver(ABC):
         in the warning.
 
         Solver implementations should not call ``_update_problem`` directly, but
-        instead call ``_load_problem`` (from within :meth:`solve`).
+        instead call ``_load_problem``.
         """
         pass
 
