@@ -108,6 +108,8 @@ class CPLEXSolver(Solver):
     """
 
     # TODO: Allow nonconvex quadratic constraints in the integer case?
+    # NOTE: When making changes, also see the section in _solve that tells CPLEX
+    #       the problem type.
     SUPPORTED = Specification.compile(
         directions=Specification.ALL,
         objectives=[
@@ -866,24 +868,21 @@ class CPLEXSolver(Solver):
         # Inform CPLEX about the problem type.
         # This seems necessary, as otherwise LP can get solved as MIP, producing
         # misleading status output (e.g. "not integer feasible").
-        conTypes   = set(c.__class__ for c in self.ext.constraints.values())
-        quadObj    = isinstance(self.ext.no.function, QuadraticExpression)
-        continuous = continuous
+        conTypes = set(c.__class__ for c in self.ext.constraints.values())
         cplexTypes = self.int.problem_type
 
-        if not conTypes and quadObj:
-            cplexType = cplexTypes.QP if continuous else cplexTypes.MIQP
-        elif conTypes.issubset(set([AffineConstraint])):
-            cplexType = cplexTypes.LP if continuous else cplexTypes.MILP
-        elif conTypes.issubset(set([AffineConstraint, SOCConstraint,
-                RSOCConstraint, ConvexQuadraticConstraint])):
-            cplexType = cplexTypes.QCP if continuous else cplexTypes.MIQCP
+        if isinstance(self.ext.no.function, QuadraticExpression):
+            if conTypes.issubset(set([AffineConstraint])):
+                cplexType = cplexTypes.QP if continuous else cplexTypes.MIQP
+            else:
+                # Assume quadratic constraint types.
+                cplexType = cplexTypes.QCP if continuous else cplexTypes.MIQCP
         else:
-            cplexType = None
-            self._verbose(
-                "PICOS is not sure how to inform CPLEX that the problem type is"
-                "'{}', and will trust CPLEX to detect this correctly."
-                .format(self.int.type))
+            if conTypes.issubset(set([AffineConstraint])):
+                cplexType = cplexTypes.LP if continuous else cplexTypes.MILP
+            else:
+                # Assume quadratic constraint types.
+                cplexType = cplexTypes.QCP if continuous else cplexTypes.MIQCP
 
         if cplexType is not None:
             self.int.set_problem_type(cplexType)
@@ -940,7 +939,7 @@ class CPLEXSolver(Solver):
                             picosDual = cvxopt.matrix(values, picosCon.size)
 
                             # Flip sign based on constraint relation.
-                            if picosCon.is_decreasing():
+                            if not picosCon.is_increasing():
                                 picosDual = -picosDual
                         elif isinstance(picosCon, SOCConstraint):
                             cplexMetaCon = self._cplexSOCC[picosCon]
