@@ -536,7 +536,7 @@ class CVXOPTSolver(Solver):
                 if isinstance(constraint, AffineConstraint):
                     if constraint.is_equality():
                         if soleq is not None:
-                            dual = (P.T * soleq)[indy:indy + consSz]
+                            dual = -(P.T * soleq)[indy:indy + consSz]
                             indy += consSz
                     else:
                         if result[zkey] is not None:
