@@ -462,7 +462,7 @@ class ECOSSolver(Solver):
 
                 if isinstance(constraint, AffineConstraint):
                     if constraint.is_equality():
-                        dual = list(solution["y"][indices])
+                        dual = list(-solution["y"][indices])
                     else:
                         dual = list(solution["z"][indices])
                 elif isinstance(constraint, SOCConstraint):
