@@ -521,7 +521,7 @@ class GLPKSolver(Solver):
                     value.append(localValue)
 
                 dual = cvxopt.matrix(value, constraint.size)
-                if constraint.is_decreasing() ^ minimizing:
+                if (not constraint.is_increasing()) ^ minimizing:
                     dual = -dual
 
                 duals[constraint] = dual
