@@ -591,7 +591,7 @@ class GurobiSolver(Solver):
                         picosDual = cvxopt.matrix(gurobiDuals, picosCon.size)
 
                         # Flip sign based on constraint relation.
-                        if picosCon.is_decreasing():
+                        if not picosCon.is_increasing():
                             picosDual = -picosDual
                     elif isinstance(picosCon, SOCConstraint):
                         gurobiMetaCon = self._gurobiSOCC[picosCon]
