@@ -800,7 +800,7 @@ class MOSEKSolver(Solver):
 
                     if isinstance(constraint, AffineConstraint) \
                     or isinstance(constraint, LMIConstraint):
-                        if constraint.is_decreasing():
+                        if not constraint.is_increasing():
                             dual = -dual
 
                     if minimizing:
