@@ -667,7 +667,7 @@ class MOSEKFusionSolver(Solver):
                 # Adjust the dual based on constraint type.
                 if isinstance(picosCon, AffineConstraint) \
                 or isinstance(picosCon, LMIConstraint):
-                    if picosCon.is_decreasing():
+                    if not picosCon.is_increasing():
                         picosDual = -picosDual
                 elif isinstance(picosCon, SOCConstraint):
                     picosDual = -picosDual
