@@ -503,7 +503,7 @@ class SCIPSolver(Solver):
                 picosDual = cvxopt.matrix(scipDuals, picosConstraint.size)
 
                 # Flip sign based on constraint relation.
-                if picosConstraint.is_decreasing():
+                if not picosConstraint.is_increasing():
                     picosDual = -picosDual
 
                 # Flip sign based on objective sense.
